==============
Pandas Connect
==============


.. image:: https://img.shields.io/pypi/v/pandas_connect.svg
        :target: https://pypi.python.org/pypi/pandas_connect

.. image:: https://img.shields.io/travis/erichamers/pandas_connect.svg
        :target: https://travis-ci.com/erichamers/pandas_connect

.. image:: https://readthedocs.org/projects/pandas-connect/badge/?version=latest
        :target: https://pandas-connect.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




Pandas connection methods for multiple databases. SQL and NoSQL.


* Free software: Apache Software License 2.0
* Documentation: https://pandas-connect.readthedocs.io.


Features
--------

* TODO

Credits
-------

